package gw
import "go.etcd.io/etcd/api/v3/etcdserverpb/gw"
Package etcdserverpb is a reverse proxy.
It translates gRPC into RESTful JSON APIs.
Index ¶
- func RegisterAuthHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
- func RegisterAuthHandlerClient(ctx context.Context, mux *runtime.ServeMux, client etcdserverpb.AuthClient) error
- func RegisterAuthHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
- func RegisterAuthHandlerServer(ctx context.Context, mux *runtime.ServeMux, server etcdserverpb.AuthServer) error
- func RegisterClusterHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
- func RegisterClusterHandlerClient(ctx context.Context, mux *runtime.ServeMux, client etcdserverpb.ClusterClient) error
- func RegisterClusterHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
- func RegisterClusterHandlerServer(ctx context.Context, mux *runtime.ServeMux, server etcdserverpb.ClusterServer) error
- func RegisterKVHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
- func RegisterKVHandlerClient(ctx context.Context, mux *runtime.ServeMux, client etcdserverpb.KVClient) error
- func RegisterKVHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
- func RegisterKVHandlerServer(ctx context.Context, mux *runtime.ServeMux, server etcdserverpb.KVServer) error
- func RegisterLeaseHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
- func RegisterLeaseHandlerClient(ctx context.Context, mux *runtime.ServeMux, client etcdserverpb.LeaseClient) error
- func RegisterLeaseHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
- func RegisterLeaseHandlerServer(ctx context.Context, mux *runtime.ServeMux, server etcdserverpb.LeaseServer) error
- func RegisterMaintenanceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
- func RegisterMaintenanceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client etcdserverpb.MaintenanceClient) error
- func RegisterMaintenanceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
- func RegisterMaintenanceHandlerServer(ctx context.Context, mux *runtime.ServeMux, server etcdserverpb.MaintenanceServer) error
- func RegisterWatchHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
- func RegisterWatchHandlerClient(ctx context.Context, mux *runtime.ServeMux, client etcdserverpb.WatchClient) error
- func RegisterWatchHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
- func RegisterWatchHandlerServer(ctx context.Context, mux *runtime.ServeMux, server etcdserverpb.WatchServer) error
Functions ¶
func RegisterAuthHandler ¶
func RegisterAuthHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
RegisterAuthHandler registers the http handlers for service Auth to "mux". The handlers forward requests to the grpc endpoint over "conn".
func RegisterAuthHandlerClient ¶
func RegisterAuthHandlerClient(ctx context.Context, mux *runtime.ServeMux, client etcdserverpb.AuthClient) error
etcdserverpb.RegisterAuthHandlerClient registers the http handlers for service Auth to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "AuthClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "AuthClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "AuthClient" to call the correct interceptors. This client ignores the HTTP middlewares.
func RegisterAuthHandlerFromEndpoint ¶
func RegisterAuthHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
RegisterAuthHandlerFromEndpoint is same as RegisterAuthHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.
func RegisterAuthHandlerServer ¶
func RegisterAuthHandlerServer(ctx context.Context, mux *runtime.ServeMux, server etcdserverpb.AuthServer) error
etcdserverpb.RegisterAuthHandlerServer registers the http handlers for service Auth to "mux". UnaryRPC :call etcdserverpb.AuthServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterAuthHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.
func RegisterClusterHandler ¶
func RegisterClusterHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
RegisterClusterHandler registers the http handlers for service Cluster to "mux". The handlers forward requests to the grpc endpoint over "conn".
func RegisterClusterHandlerClient ¶
func RegisterClusterHandlerClient(ctx context.Context, mux *runtime.ServeMux, client etcdserverpb.ClusterClient) error
etcdserverpb.RegisterClusterHandlerClient registers the http handlers for service Cluster to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "ClusterClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "ClusterClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "ClusterClient" to call the correct interceptors. This client ignores the HTTP middlewares.
func RegisterClusterHandlerFromEndpoint ¶
func RegisterClusterHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
RegisterClusterHandlerFromEndpoint is same as RegisterClusterHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.
func RegisterClusterHandlerServer ¶
func RegisterClusterHandlerServer(ctx context.Context, mux *runtime.ServeMux, server etcdserverpb.ClusterServer) error
etcdserverpb.RegisterClusterHandlerServer registers the http handlers for service Cluster to "mux". UnaryRPC :call etcdserverpb.ClusterServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterClusterHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.
func RegisterKVHandler ¶
func RegisterKVHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
RegisterKVHandler registers the http handlers for service KV to "mux". The handlers forward requests to the grpc endpoint over "conn".
func RegisterKVHandlerClient ¶
func RegisterKVHandlerClient(ctx context.Context, mux *runtime.ServeMux, client etcdserverpb.KVClient) error
etcdserverpb.RegisterKVHandlerClient registers the http handlers for service KV to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "KVClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "KVClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "KVClient" to call the correct interceptors. This client ignores the HTTP middlewares.
func RegisterKVHandlerFromEndpoint ¶
func RegisterKVHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
RegisterKVHandlerFromEndpoint is same as RegisterKVHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.
func RegisterKVHandlerServer ¶
func RegisterKVHandlerServer(ctx context.Context, mux *runtime.ServeMux, server etcdserverpb.KVServer) error
etcdserverpb.RegisterKVHandlerServer registers the http handlers for service KV to "mux". UnaryRPC :call etcdserverpb.KVServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterKVHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.
func RegisterLeaseHandler ¶
func RegisterLeaseHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
RegisterLeaseHandler registers the http handlers for service Lease to "mux". The handlers forward requests to the grpc endpoint over "conn".
func RegisterLeaseHandlerClient ¶
func RegisterLeaseHandlerClient(ctx context.Context, mux *runtime.ServeMux, client etcdserverpb.LeaseClient) error
etcdserverpb.RegisterLeaseHandlerClient registers the http handlers for service Lease to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "LeaseClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "LeaseClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "LeaseClient" to call the correct interceptors. This client ignores the HTTP middlewares.
func RegisterLeaseHandlerFromEndpoint ¶
func RegisterLeaseHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
RegisterLeaseHandlerFromEndpoint is same as RegisterLeaseHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.
func RegisterLeaseHandlerServer ¶
func RegisterLeaseHandlerServer(ctx context.Context, mux *runtime.ServeMux, server etcdserverpb.LeaseServer) error
etcdserverpb.RegisterLeaseHandlerServer registers the http handlers for service Lease to "mux". UnaryRPC :call etcdserverpb.LeaseServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterLeaseHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.
func RegisterMaintenanceHandler ¶
func RegisterMaintenanceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
RegisterMaintenanceHandler registers the http handlers for service Maintenance to "mux". The handlers forward requests to the grpc endpoint over "conn".
func RegisterMaintenanceHandlerClient ¶
func RegisterMaintenanceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client etcdserverpb.MaintenanceClient) error
etcdserverpb.RegisterMaintenanceHandlerClient registers the http handlers for service Maintenance to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "MaintenanceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "MaintenanceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "MaintenanceClient" to call the correct interceptors. This client ignores the HTTP middlewares.
func RegisterMaintenanceHandlerFromEndpoint ¶
func RegisterMaintenanceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
RegisterMaintenanceHandlerFromEndpoint is same as RegisterMaintenanceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.
func RegisterMaintenanceHandlerServer ¶
func RegisterMaintenanceHandlerServer(ctx context.Context, mux *runtime.ServeMux, server etcdserverpb.MaintenanceServer) error
etcdserverpb.RegisterMaintenanceHandlerServer registers the http handlers for service Maintenance to "mux". UnaryRPC :call etcdserverpb.MaintenanceServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterMaintenanceHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.
func RegisterWatchHandler ¶
func RegisterWatchHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
RegisterWatchHandler registers the http handlers for service Watch to "mux". The handlers forward requests to the grpc endpoint over "conn".
func RegisterWatchHandlerClient ¶
func RegisterWatchHandlerClient(ctx context.Context, mux *runtime.ServeMux, client etcdserverpb.WatchClient) error
etcdserverpb.RegisterWatchHandlerClient registers the http handlers for service Watch to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "WatchClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "WatchClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "WatchClient" to call the correct interceptors. This client ignores the HTTP middlewares.
func RegisterWatchHandlerFromEndpoint ¶
func RegisterWatchHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
RegisterWatchHandlerFromEndpoint is same as RegisterWatchHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.
func RegisterWatchHandlerServer ¶
func RegisterWatchHandlerServer(ctx context.Context, mux *runtime.ServeMux, server etcdserverpb.WatchServer) error
etcdserverpb.RegisterWatchHandlerServer registers the http handlers for service Watch to "mux". UnaryRPC :call etcdserverpb.WatchServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterWatchHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.
Source Files ¶
rpc.pb.gw.go
- Version
- v3.6.7 (latest)
- Published
- Dec 17, 2025
- Platform
- linux/amd64
- Imports
- 14 packages
- Last checked
- 4 months ago –
Tools for package owners.